@@ -14,7 +14,7 @@ typedef int my_int;
 typedef my_int int2;
 typedef int2   int3;
 
-typedef loop loop;
+
 
 typedef int loop2;
 typedef loop2 loop2;
@@ -30,7 +30,7 @@ my_int i1;
 int2 i2;
 int3 i3;
 
-loop l1;
+
 loop2 l2;
 
 new_type t1;
