@@ -25,12 +25,8 @@
 #include "cscmarshal.h"
 #include "htmlengine-edit-clueflowstyle.h"
 #include "htmlengine-edit-copy.h"
-#include "htmlengine-edit-cut.h"
-#include "htmlengine-edit-delete.h"
 #include "htmlengine-edit-fontstyle.h"
-#include "htmlengine-edit-insert.h"
 #include "htmlengine-edit-movement.h"
-#include "htmlengine-edit-paste.h"
 #include "htmlengine-edit.h"
 
 #include "cschtml-embedded.h"
@@ -741,7 +737,6 @@ button_press_event (GtkWidget *widget,
 			return TRUE;
 			break;
 		case 2:
-			csc_html_request_paste (widget, event->time);
 			return TRUE;
 			break;
 		default:
@@ -881,45 +876,7 @@ selection_received (GtkWidget *widget,
 		    GtkSelectionData *selection_data,
 		    guint time)
 {
-	g_return_if_fail (widget != NULL);
-	g_return_if_fail (GTK_IS_CSCHTML (widget));
-	g_return_if_fail (selection_data != NULL);
-
-	// printf("got selection from system\n");
-
-#if 0
-	/* **** IMPORTANT **** Check to see if retrieval succeeded  */
-	/* If we have more selection types we can ask for, try the next one,
-	   until there are none left */
-	if (selection_data->length < 0) {
-		struct _zvtprivate *zp = _ZVT_PRIVATE(widget);
-
-		/* now, try again with next selection type */
-		if (csc_html_request_paste(widget, zp->lastselectiontype+1, time)==0)
-			g_print ("Selection retrieval failed\n");
-		return;
-	}
-#endif
-
-	/* we will get a selection type of atom(UTF-8) for utf text,
-	   perhaps that needs to do something different if the terminal
-	   isn't actually in utf8 mode? */
-
-	/* Make sure we got the data in the expected form */
-	if (selection_data->type != GDK_SELECTION_TYPE_STRING) {
-		g_print ("Selection \"STRING\" was not returned as strings!\n");
-		return;
-	}
-
-	if (selection_data->length) {
-		// printf ("selection text \"%.*s\"\n",
-		//	selection_data->length, selection_data->data);
-
-		html_engine_disable_selection (CSC_HTML (widget)->engine);
-		html_engine_insert (CSC_HTML (widget)->engine,
-				    selection_data->data,
-				    selection_data->length);
-	}
+  /* No longer needed, could be removed */
 }
 
 int
@@ -1370,39 +1327,6 @@ csc_html_jump_to_anchor (CscHTML *html,
 	return html_engine_goto_anchor (html->engine, anchor);
 }
 
-
-gboolean
-csc_html_save (CscHTML *html,
-	       CscHTMLSaveReceiverFn receiver,
-	       gpointer data)
-{
-	g_return_val_if_fail (html != NULL, FALSE);
-	g_return_val_if_fail (GTK_IS_CSCHTML (html), FALSE);
-	g_return_val_if_fail (receiver != NULL, FALSE);
-
-	return html_engine_save (html->engine, receiver, data);
-}
-
-gboolean
-csc_html_export (CscHTML *html,
-		 const char *type,
-		 CscHTMLSaveReceiverFn receiver,
-		 gpointer data)
-{
-	g_return_val_if_fail (html != NULL, FALSE);
-	g_return_val_if_fail (GTK_IS_CSCHTML (html), FALSE);
-	g_return_val_if_fail (receiver != NULL, FALSE);
-
-	if (strcmp (type, "text/html") == 0) {
-		return html_engine_save (html->engine, receiver, data);
-	} else if (strcmp (type, "text/plain") == 0) {
-		return html_engine_save_plain (html->engine, receiver,
-					       data);
-	} else {
-		return FALSE;
-	}
-}
-
 
 void
 csc_html_private_calc_scrollbars (CscHTML *html)
@@ -1535,15 +1459,6 @@ csc_html_align_paragraph (CscHTML *html,
 
 /* Clipboard operations.  */
 
-void
-csc_html_cut (CscHTML *html)
-{
-	g_return_if_fail (html != NULL);
-	g_return_if_fail (GTK_IS_CSCHTML (html));
-
-	html_engine_cut (html->engine, TRUE);
-}
-
 void
 csc_html_copy (CscHTML *html)
 {
@@ -1553,36 +1468,6 @@ csc_html_copy (CscHTML *html)
 	html_engine_copy (html->engine);
 }
 
-void
-csc_html_paste (CscHTML *html)
-{
-	g_return_if_fail (html != NULL);
-	g_return_if_fail (GTK_IS_CSCHTML (html));
-
-	html_engine_paste (html->engine, TRUE);
-}
-
-
-/* Undo/redo.  */
-
-void
-csc_html_undo (CscHTML *html)
-{
-	g_return_if_fail (html != NULL);
-	g_return_if_fail (GTK_IS_CSCHTML (html));
-
-	html_engine_undo (html->engine);
-}
-
-void
-csc_html_redo (CscHTML *html)
-{
-	g_return_if_fail (html != NULL);
-	g_return_if_fail (GTK_IS_CSCHTML (html));
-
-	html_engine_redo (html->engine);
-}
-
 /* misc utils */
 
 void
