@@ -892,235 +892,6 @@ append_selection_string (HTMLObject *self,
 	g_string_append_c (buffer, '\n');
 }
 
-
-/* Saving support.  */
-
-static gboolean
-write_indentation_tags_helper (HTMLEngineSaveState *state,
-			       guint last_value,
-			       guint new_value,
-			       const gchar *tag)
-{
-	guint i, j;
-
-	if (new_value > last_value) {
-		for (i = last_value; i < new_value; i++) {
-			for (j = 0; j < i; j++) {
-				if (! html_engine_save_output_string (state, "    "))
-					return FALSE;
-			}
-
-			if (! html_engine_save_output_string (state, "<%s>\n", tag))
-				return FALSE;
-		}
-	} else {
-		for (i = last_value; i > new_value; i--) {
-			if (i > 1) {
-				for (j = 0; j < i - 1; j++) {
-					if (! html_engine_save_output_string (state, "    "))
-						return FALSE;
-				}
-			}
-
-			if (! html_engine_save_output_string (state, "</%s>\n", tag))
-				return FALSE;
-		}
-	}
-
-	return TRUE;
-}
-
-static gboolean
-write_indentation_tags (HTMLClueFlow *self,
-			HTMLEngineSaveState *state)
-{
-	if (state->last_level == self->level)
-		return TRUE;
-
-	/* FIXME should use UL appropriately.  */
-
-	if (! write_indentation_tags_helper (state,
-					     state->last_level,
-					     self->level,
-					     "BLOCKQUOTE"))
-		return FALSE;
-
-	state->last_level = self->level;
-
-	return TRUE;
-}
-
-static const gchar *
-get_tag_for_style (const HTMLClueFlow *flow)
-{
-	switch (flow->style) {
-	case HTML_CLUEFLOW_STYLE_NORMAL:
-		return NULL;
-	case HTML_CLUEFLOW_STYLE_H1:
-		return "H1";
-	case HTML_CLUEFLOW_STYLE_H2:
-		return "H2";
-	case HTML_CLUEFLOW_STYLE_H3:
-		return "H3";
-	case HTML_CLUEFLOW_STYLE_H4:
-		return "H4";
-	case HTML_CLUEFLOW_STYLE_H5:
-		return "H5";
-	case HTML_CLUEFLOW_STYLE_H6:
-		return "H6";
-	case HTML_CLUEFLOW_STYLE_ADDRESS:
-		return "ADDRESS";
-	case HTML_CLUEFLOW_STYLE_PRE:	
-		return "PRE";
-	case HTML_CLUEFLOW_STYLE_ITEMDOTTED:
-	case HTML_CLUEFLOW_STYLE_ITEMROMAN:
-	case HTML_CLUEFLOW_STYLE_ITEMDIGIT:
-		return "LI";
-	default:
-		g_warning ("Unknown HTMLClueFlowStyle %d", flow->style);
-		return NULL;
-	}
-}
-
-static const gchar *
-get_tag_for_item_group (const HTMLClueFlow *flow)
-{
-	switch (flow->style) {
-	case HTML_CLUEFLOW_STYLE_ITEMDOTTED:
-		return "UL";
-	case HTML_CLUEFLOW_STYLE_ITEMROMAN:
-	case HTML_CLUEFLOW_STYLE_ITEMDIGIT:
-		return "OL";
-	default:
-		g_warning ("Unknown HTMLClueFlowStyle %d", flow->style);
-		return NULL;
-	}
-}
-
-static const gchar *
-halign_to_string (HTMLHAlignType halign)
-{
-	switch (halign) {
-	case HTML_HALIGN_RIGHT:
-		return "RIGHT";
-	case HTML_HALIGN_CENTER:
-		return "CENTER";
-	case HTML_HALIGN_LEFT:
-	case HTML_HALIGN_NONE:
-	default:
-		return "LEFT";
-	}
-}
-
-static gboolean 
-is_similar (HTMLObject *self, HTMLObject *friend)
-{
-	if (friend &&  HTML_OBJECT_TYPE (friend) == HTML_TYPE_CLUEFLOW) {
-		if ((HTML_CLUEFLOW (friend)->style == HTML_CLUEFLOW (self)->style)
-		    && (HTML_CLUEFLOW (friend)->level == HTML_CLUEFLOW (self)->level)) {
-				return TRUE;
-		}
-	}
-	return FALSE;
-}
-
-static gboolean
-save (HTMLObject *self,
-      HTMLEngineSaveState *state)
-{
-	HTMLClueFlow *clueflow;
-	HTMLHAlignType halign;
-	const gchar *tag;
-	gboolean start = TRUE, end = TRUE;
-
-	clueflow = HTML_CLUEFLOW (self);
-	halign = HTML_CLUE (self)->halign;
-
-	if (! write_indentation_tags (clueflow, state))
-		return FALSE;
-
-	tag = get_tag_for_style (clueflow);
-
-	if (is_similar (self, self->prev))
-		start = FALSE;
-
-	if (is_similar (self, self->next))
-		end = FALSE;
-	
-	if (self->prev != NULL && ! is_item (clueflow)
-	    && HTML_OBJECT_TYPE (HTML_CLUE (self)->tail) != HTML_TYPE_RULE) {
-		if (HTML_CLUEFLOW (self)->style != HTML_CLUEFLOW_STYLE_PRE) {
-			/* This is a nasty hack: the rule takes all of the space, so we
-			   don't want it to create a new newline if it's the last
-			   element on the paragraph.  Also, everything but the "normal"
-			   paragraph style would get an extra newline if we add a
-			   `<BR>'.  */
-			html_engine_save_output_string (state, "<BR>\n");
-		} else {
-			html_engine_save_output_string (state, "\n");
-		}
-	}
-
-	/* Alignment tag.  */
-	if (halign != HTML_HALIGN_NONE && halign != HTML_HALIGN_LEFT) {
-		if (! html_engine_save_output_string (state, "<DIV ALIGN=%s>\n", halign_to_string (halign)))
-			return FALSE;
-	}
-
-	if (start && is_item (clueflow)) {
-		if (! html_engine_save_output_string (state, "<%s>\n",
-						      get_tag_for_item_group (HTML_CLUEFLOW (self))))
-			return FALSE;
-	}		
-
-	/* Start tag.  */
-	if (tag != NULL && (start || is_item (clueflow))
-	    && (! html_engine_save_output_string (state, "<%s>", tag)))
-		return FALSE;
-
-	/* Paragraph's content.  */
-	if (! HTML_OBJECT_CLASS (&html_clue_class)->save (self, state))
-		return FALSE;
-
-	/* End tag.  */
-	if (tag && (end || is_item (clueflow))) {
-		if (! html_engine_save_output_string (state, "</%s>", tag))
-			return FALSE;
-	}
-
-	if (end && is_item (clueflow)) {
-		if (! html_engine_save_output_string (state, "\n</%s>",
-						      get_tag_for_item_group (HTML_CLUEFLOW (self))))
-			return FALSE;
-	}		
-
-	/* Close alignment tag.  */
-	if (halign != HTML_HALIGN_NONE && halign != HTML_HALIGN_LEFT) {
-		if (! html_engine_save_output_string (state, "</DIV>\n"))
-			return FALSE;
-	} else if (tag != NULL) {
-		if (! html_engine_save_output_string (state, "\n"))
-			return FALSE;
-	}
-
-	return TRUE;
-}
-
-static gboolean
-save_plain (HTMLObject *self,
-	    HTMLEngineSaveState *state)
-{
-
-	/* Paragraph's content.  */
-	if (! HTML_OBJECT_CLASS (&html_clue_class)->save_plain (self, state))
-		return FALSE;
-
-	if (!html_engine_save_output_string (state, "\n"))
-		return FALSE;
-	
-	return TRUE;
-}
-
 
 static gint
 check_page_split (HTMLObject *self,
@@ -1460,8 +1231,6 @@ html_clueflow_class_init (HTMLClueFlowClass *klass,
 	object_class->calc_min_width = calc_min_width;
 	object_class->calc_preferred_width = calc_preferred_width;
 	object_class->draw = draw;
-	object_class->save = save;
-	object_class->save_plain = save_plain;
 	object_class->check_page_split = check_page_split;
 	object_class->check_point = check_point;
 	object_class->append_selection_string = append_selection_string;
