@@ -345,64 +345,6 @@ draw (HTMLObject *o,
 	}
 }
 
-static gboolean
-save (HTMLObject *self,
-      HTMLEngineSaveState *state)
-{
-	HTMLImage *image;
-
-	g_return_val_if_fail (self != NULL, FALSE);
-	g_return_val_if_fail (state != NULL, FALSE);
-	
-	image = HTML_IMAGE (self);
-	
-	if (!html_engine_save_output_string (state, "<IMG SRC=\"%s\"", image->image_ptr->url))
-	        return FALSE;	
-
-	if (image->specified_width > 0) {
-		if (!html_engine_save_output_string (state, " WIDTH=\"%d\"", image->specified_height))
-			return FALSE;
-	} else if (self->percent) {
-		if (!html_engine_save_output_string (state, " WIDTH=\"%d\%\"", self->percent))
-			return FALSE;
-	}
-
-	/* FIXME percent heights are supported in netscape/mozilla */
-	if (image->specified_height > 0) {
-		if (!html_engine_save_output_string (state, " HEIGHT=\"%d\"", image->specified_height))
-			return FALSE;
-	}
-
-	if (image->vspace) {
-		if (!html_engine_save_output_string (state, " VSPACE=\"%d\"", image->vspace))
-			return FALSE;
-	}
-
-	if (image->hspace) {
-		if (!html_engine_save_output_string (state, " HSPACE=\"%d\"", image->hspace))
-			return FALSE;
-	}
-
-	if (image->vspace) {
-		if (!html_engine_save_output_string (state, " VSPACE=\"%d\"", image->vspace))
-			return FALSE;
-	}
-
-	/* FIXME this is the default set in htmlengine.c but there is no real way to tell
-	 * if the usr specified it directly
-	 */
-	if (image->border != 2) {
-		if (!html_engine_save_output_string (state, " BORDER=\"%d\"", image->border))
-			return FALSE;
-	}
-
-	/* FIXME we are not preserving alt tags */
-	if (!html_engine_save_output_string (state, ">"))
-		return FALSE;
-	
-	return TRUE;
-}
-
 static const gchar *
 get_url (HTMLObject *o)
 {
@@ -466,7 +408,6 @@ html_image_class_init (HTMLImageClass *image_class,
 	object_class->get_target = get_target;
 	object_class->accepts_cursor = accepts_cursor;
 	object_class->get_valign = get_valign;
-	object_class->save = save;
 
 	parent_class = &html_object_class;
 }
